<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

<!--
    IMPORTANT: (output encoding ) ne marche que pour xlm.load(), 
    mais pas pour xml.save(). Dans le flux html en sortie, il faut 
    donc remplacer manuellement la sequence par defaut:
        META http-equiv="Content-Type" content="text/html; charset=UTF-16"
    par:
        META http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"
-->

<!-- variablesXSL  (Definies directement par Word)
$isExtern / chainages internes ou externes
	0=local anchors 
	1=extern anchors + header et footer HTML
$isToc / uniquement la table des matieres
	0= false / tout le texte
	1= true	 / la toc uniqmt
$isPath / affiche le path d'acces
	0= false / pas de path
	1= true	 / affiche le PATH
-->

<xsl:variable name="isExtern" select="0"/>
<xsl:variable name="isToc" select="0"/>
<xsl:variable name="isPath" select="0"/>

<!-- variablesURL (Modifier !) --> 

<xsl:variable name="urlLGT">http://www.in3activa.org/doc/fr/LGT-FR.html</xsl:variable>
<xsl:variable name="urlCITI">http://www.in3activa.org/doc/fr/CITI-FR.html</xsl:variable>
<xsl:variable name="urlMAIL">&#105;rm@&#105;n3act&#105;va.org</xsl:variable>
<xsl:variable name="urlCSS">citi.css</xsl:variable>

<!-- variablesLANG (Modifier !) -->

<xsl:variable name="langArticle">Art.</xsl:variable> 
<xsl:variable name="urlROOT">index.html</xsl:variable> 
<xsl:variable name="langROOT">[ Premiere page ]</xsl:variable> 
<xsl:variable name="urlZIPu">http://www.in3activa.org/doc/fr/CITI-FRv1zu.html.zip</xsl:variable><!-- fichier unique -->
<xsl:variable name="langZIPu"> [ ZIP (un grand fichier) ] </xsl:variable> 
<xsl:variable name="urlZIPm">http://www.in3activa.org/doc/fr/CITI-FRv1zm.html.zip</xsl:variable><!-- fichier multiple-->
<xsl:variable name="langZIPm"> [ ZIP (plusieurs fichiers) ] </xsl:variable> 
<xsl:variable name="urlPDF">http://www.in3activa.org/doc/fr/CITI-FRv1r5.pdf</xsl:variable><!-- fichier multiple-->
<xsl:variable name="langPDF"> [ Format PDF ] </xsl:variable> 
<xsl:variable name="urlDOC">http://www.in3activa.org/doc/fr/CITI-FRv1r5.rtf.zip</xsl:variable><!-- fichier multiple-->
<xsl:variable name="langDOC"> [ Format RTF (.zip) ] </xsl:variable> 

<!-- Expansion des variables-->

<xsl:template match="URLLGT">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlLGT"/></xsl:attribute>
	<xsl:value-of select="$urlLGT"/>
	</A>
</xsl:template>
<xsl:template match="URLCITI">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlCITI"/></xsl:attribute>
	<xsl:value-of select="$urlCITI"/>
	</A>
</xsl:template>
<xsl:template match="URLMAIL">
	<A>
	<xsl:attribute name="href">mailto:<xsl:value-of select="$urlMAIL"/></xsl:attribute>
	<xsl:value-of select="$urlMAIL"/>
	</A>
</xsl:template>
<xsl:template match="URLCSS">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlCSS"/></xsl:attribute>
	<xsl:value-of select="$urlCSS"/>
	</A>
</xsl:template>

<xsl:template match="LANGARTICLE">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$langArticle"/></xsl:attribute>
	<xsl:value-of select="$langArticle"/>
	</A>
</xsl:template>

<!-- TOKENS pour variables -->
<xsl:template name="tokenROOT">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlROOT"/></xsl:attribute>
	<xsl:value-of select="$langROOT"/>
	</A>
</xsl:template>
<xsl:template name="tokenZIPu">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlZIPu"/></xsl:attribute>
	<xsl:value-of select="$langZIPu"/>
	</A>
</xsl:template>
<xsl:template name="tokenZIPm">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlZIPm"/></xsl:attribute>
	<xsl:value-of select="$langZIPm"/>
	</A>
</xsl:template>
<xsl:template name="tokenPDF">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlPDF"/></xsl:attribute>
	<xsl:value-of select="$langPDF"/>
	</A>
</xsl:template>
<xsl:template name="tokenDOC">
	<A>
	<xsl:attribute name="href"><xsl:value-of select="$urlDOC"/></xsl:attribute>
	<xsl:value-of select="$langDOC"/>
	</A>
</xsl:template>




<!-- Erreurs -->
<xsl:template match="*|@*">
  <SPAN STYLE="background-color:yellow">
    <xsl:attribute name="title">&lt;<xsl:value-of select="."/>&gt;</xsl:attribute>
    <xsl:apply-templates/>
  </SPAN>
</xsl:template>


<!-- ROOT TEMPLATE 
	 templates header et footer permettent 
	 de sortir au format HTML
-->
<xsl:template match="/">
	<xsl:call-template name="header"/>
		<xsl:apply-templates />	
	<xsl:call-template name="footer"/>
</xsl:template>

<xsl:template name="header">
	<xsl:text disable-output-escaping="yes">&lt;HTML&gt;</xsl:text>	

	<HEAD>
    <!--<META http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />-->
	<LINK REL="stylesheet" TYPE="text/css" >
		<xsl:attribute name="HREF"><xsl:value-of select="$urlCSS"/>
			</xsl:attribute>
		</LINK>

	<TITLE><xsl:value-of select="ITEM"/></TITLE>	<!-- sans expansion -->
	</HEAD>
	<xsl:text disable-output-escaping="yes">&lt;BODY&gt;</xsl:text>
	<DIV class="ROOT" >In3activa.org</DIV>
	<BR/>
	<DIV class="ref">
		<xsl:call-template name="tokenROOT"/>
		<xsl:call-template name="tokenZIPu"/>
		<xsl:call-template name="tokenZIPm"/>
		<xsl:call-template name="tokenPDF"/>
		<xsl:call-template name="tokenDOC"/>
	</DIV>
</xsl:template>

<xsl:template name="footer">
	<HR class="bot"/>
	<xsl:apply-templates select="/H0/H9[1]"/>	<!-- premier copyright -->
	<xsl:text disable-output-escaping="yes">&lt;/BODY&gt;&lt;/HTML&gt;</xsl:text>
</xsl:template>

<!-- Routine de construction de HREF's-->
<xsl:template name="makeHREF">
<A>
	<xsl:attribute name="HREF">
		<xsl:choose><!-- si local au document -->
			<xsl:when test="$isExtern=0">#<xsl:value-of select="@id"/>
				</xsl:when>	
			<xsl:otherwise><xsl:value-of select="@id"/>.html
				</xsl:otherwise>	
			</xsl:choose>
		</xsl:attribute>
	<xsl:apply-templates select="TITRE|CHAPITRE|ARTICLE"/>
	<xsl:value-of select="ITEM"/>
</A>
</xsl:template>

<xsl:template name="makeAnchor">
<A><xsl:attribute name="NAME"><xsl:value-of select="@id"/></xsl:attribute></A>
</xsl:template>


<!-- PATH : 
	creation des ancestors via call-template makePath 
	Appel: makeHREF
-->  
<xsl:template name="makePath">
	<xsl:if test="$isPath=1">
	<DIV class="path">
		<xsl:for-each select="/H1|ancestor::H1|ancestor::H2|ancestor::H3">
			<xsl:call-template name="makeHREF"/>
			<BR/>
		</xsl:for-each >
	</DIV>
	</xsl:if>
</xsl:template>

<!-- TABLE DES MATIERES : 
	creation des childs via apply-templates mode=toc
	Appel: makeHREF
	Appel: makeHREF

-->
<xsl:template match="H1|H2|H3|H4|H7" mode="toc">
  <DIV class="toc">
	<xsl:call-template name="makeHREF"/>
	<xsl:apply-templates select="H2|H3" mode="toc"/>
  </DIV>
 </xsl:template>

<!-- LIAISONS <CHN> 
	creation des chainages donnes en attributs 
	creation des tips 
	Appel: mkChnHREF qui construit HREF
		   et determine le titre d'apres le node referenced
-->
<xsl:template match="CHN">
	<DIV class="chn">
		<xsl:if test="$isPath=0">
			<xsl:apply-templates select="@parent"/>
		</xsl:if>
		<xsl:apply-templates select="@retour"/>
		<xsl:apply-templates select="@suite"/>
		<xsl:if test="$isPath=0">
			<xsl:apply-templates select="@sommaire"/>
		</xsl:if>
	</DIV>
</xsl:template>


<xsl:template match="@suite">
	<A><xsl:call-template name="mkChnHREF"/>[&gt;&gt;]</A>
	</xsl:template>
<xsl:template match="@retour">
	<A><xsl:call-template name="mkChnHREF"/>[&lt;&lt;]</A>
	</xsl:template>
<xsl:template match="@parent">
	<A><xsl:call-template name="mkChnHREF"/>[|&lt;&lt;]</A>
	</xsl:template>
<xsl:template match="@sommaire">
	<A><xsl:call-template name="mkChnHREF"/>[^]</A>
	</xsl:template>

<xsl:template name="mkChnHREF">
	<xsl:attribute name="HREF">
		<xsl:choose><!-- si local au document -->
			<xsl:when test="$isExtern=0">#<xsl:value-of select="current()"/></xsl:when>	
			<xsl:otherwise><xsl:value-of select="current()"/>.html</xsl:otherwise>	
			</xsl:choose>
		</xsl:attribute>
	<xsl:attribute name="title">
		<xsl:apply-templates select="//*[@id=current()]" mode ="tips"/>
	</xsl:attribute>
</xsl:template>

<xsl:template match="H0|H1|H2|H3|H4|H7" mode="tips">
<xsl:apply-templates select="TITRE|CHAPITRE|ARTICLE"/> <xsl:value-of select="ITEM"/> </xsl:template>


<!-- Contenu des chaines -->

<xsl:template match="text()"><xsl:value-of select="."/></xsl:template>
<xsl:template match="I"><I><xsl:apply-templates /></I></xsl:template>
<xsl:template match="BR"><BR/></xsl:template>
<xsl:template match="SYMOELIG">&#339;</xsl:template>
<xsl:template match="SYMCOPY">&#169;</xsl:template>
<xsl:template match="SYMREG"><sup>&#174;</sup></xsl:template>
<xsl:template match="INTERNETC">
<a target='_blank' href='http://www.internet-copyright.org/'>Internet&#169;</a>
</xsl:template>
<xsl:template match="ITEM">	<xsl:apply-templates />	</xsl:template>
<xsl:template match="ARTICLE"> <xsl:value-of select="$langArticle"/><xsl:value-of select="@num"/>: </xsl:template>
<xsl:template match="CHAPITRE"><!--Capitulo--><xsl:number level="multiple" format="I.1. " count="//H2|H3"/></xsl:template>
<xsl:template match="TITRE"><!--Titulo--><xsl:number level="multiple" format="I. " count="//H2"/></xsl:template>

<!-- Root H0 Document -->
<xsl:template match="H0">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>

    <!-- Titre complet en premiere page -->
    <DIV class="H0">
		<xsl:apply-templates select="ITEM"/>
	</DIV>


	<!-- IRM 4/2003 
     - premier copyright -
    xsl:apply-templates select="H9"/
    -->

	<xsl:apply-templates select="H1" mode="toc"/> <!-- Table des matieres -->
	<xsl:if test="$isToc=0">
		<xsl:apply-templates select="H1"/>	<!-- Affiche le document -->
	</xsl:if>
	<xsl:apply-templates select="CHN"/>	<!-- chainages inferieurs -->
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
  </xsl:template>


<!--  Style H1 Document -->
  <xsl:template match="H1">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>
	<xsl:call-template name="makePath" />
	<xsl:apply-templates select="CHN"/><!--Chainages -->
	<DIV class="H1">
		<xsl:apply-templates select="ITEM"/>
	</DIV>
	<xsl:apply-templates select="H9"/>	<!-- premier copyright -->
	<xsl:apply-templates select="H2|H3|H4|H7" mode="toc"/> <!-- Table des matieres -->
	<xsl:if test="$isToc=0">
		<DIV STYLE="margin-left:1em"><xsl:apply-templates select="H2|H3|H4|H7|H8|H9[position()>1]"/></DIV>
	</xsl:if>
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
  </xsl:template>

<!-- Style H2 Titre -->
  <xsl:template match="H2">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>
	<xsl:call-template name="makePath" />
	<xsl:apply-templates select="CHN"/><!--Chainages -->
	<DIV class="H2">
		<xsl:apply-templates select="TITRE"/>
		<xsl:value-of select="ITEM"/>
	</DIV>
	<xsl:apply-templates select="H3|H4" mode="toc"/> <!-- Table des matieres -->
	<xsl:if test="$isToc=0">
		<DIV STYLE="margin-left:1em"><xsl:apply-templates select="H3|H4|H5|H6|H8|H9"/></DIV>
	</xsl:if>
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
  </xsl:template>

<!-- Style H3 Chapitre -->
  <xsl:template match="H3">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>
	<xsl:call-template name="makePath" />
	<xsl:apply-templates select="CHN"/>
	<DIV class="H3">
		<xsl:apply-templates select="CHAPITRE"/>
		<xsl:apply-templates select="ITEM"/>
	</DIV>
	<xsl:apply-templates select="H4" mode="toc"/> <!-- Table des matieres -->
	<xsl:if test="$isToc=0">
		<DIV STYLE="margin-left:1em"><xsl:apply-templates select="H4|H5|H6|H8|H9"/></DIV>
	</xsl:if>
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
  </xsl:template>

<!--  Style H4 Article -->
  <xsl:template match="H4">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>
	<xsl:call-template name="makePath" />
	<xsl:apply-templates select="CHN"/>
	<DIV class="H4">
		<xsl:apply-templates select="ARTICLE"/>
		<xsl:apply-templates select="ITEM"/>
	</DIV>
	<OL class="dec"><xsl:apply-templates select="H5|H6|H8"/></OL>
	<xsl:apply-templates select="CHN"/><!--Chainages -->
	<xsl:apply-templates select="H9"/>
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
  </xsl:template>

<!--  Style H5 enumeration 1)...2) -->
  <xsl:template match="H5">
  <DIV class="H5">
		<xsl:call-template name="makeAnchor"/>
		<LI ><xsl:apply-templates select="ITEM"/></LI>
  </DIV>
	<xsl:if test="H6">
		<OL class="abc">
			<xsl:apply-templates select="H6"/>
		</OL>
	</xsl:if>
	<xsl:apply-templates select="H9"/>
</xsl:template>

<!--  Style H6 enumeration a)...b) -->
  <xsl:template match="H6">
  <xsl:call-template name="makeAnchor"/>
  <DIV class="H6">
	  <LI ><xsl:apply-templates select="ITEM"/></LI>
  </DIV>
 <xsl:apply-templates select="H9"/>
  </xsl:template>

<!--  Style H7 sous-titre introduction -->
<xsl:template match="H7">
	<xsl:if test="$isExtern=1"><xsl:call-template name="header"/></xsl:if>
	<xsl:call-template name="makeAnchor"/>
	<HR class="top"/>
	<xsl:call-template name="makePath" />
	<xsl:apply-templates select="CHN"/>
	<DIV class="H7">
		<xsl:apply-templates select="ITEM"/>
	</DIV>
	<xsl:apply-templates select="H8"/>
	<xsl:if test="$isToc=0">
	    <xsl:apply-templates select="CHN"/>
	</xsl:if>
	<xsl:if test="$isExtern=1"><xsl:call-template name="footer"/></xsl:if>
</xsl:template>

<!--  Style H8 paragraphe de texte -->
  <xsl:template match="H8">
  <DIV class="H8">
		<xsl:call-template name="makeAnchor"/>
        <xsl:apply-templates select="ITEM"/>
  </DIV>
  <xsl:apply-templates select="H9"/>
  </xsl:template>

<!--  Style H9 signature -->
  <xsl:template match="H9">
  <DIV class="H9">
	<xsl:call-template name="makeAnchor"/>
	<xsl:apply-templates select="ITEM"/>
  </DIV>
  </xsl:template>

</xsl:stylesheet>